@@ -1,3 +1,3 @@
 from agilize.agilize import (Agilize, Company, Competence, Prolabore,  # noqa
-                             Prolabores)
+                             Prolabores, Tax, Taxes)
 from agilize.client import Client  # noqa
